@@ -1,3 +1,4 @@
+import django
 from django.core.exceptions import ValidationError
 from django.db import models
 
@@ -8,13 +9,12 @@ from .formfields import MACAddressField as MACAddressFormField
 from . import default_dialect, format_mac, mac_linux
 
 import warnings
-                 
+
 class MACAddressField(models.Field):
     description = "A MAC address validated by netaddr.EUI"
     empty_strings_allowed = False
-    __metaclass__ = models.SubfieldBase
     dialect = None
-    
+
     def __init__(self, *args, **kwargs):
         self.integer = kwargs.pop('integer', True)
         if not self.integer: # If storing MAC address as string, set max_length to default (17) or use supplied kwarg value.
@@ -44,12 +44,12 @@ class MACAddressField(models.Field):
             DeprecationWarning,
         )
         cls.dialect = new_dialect_clazz
-    
+
     def get_prep_value(self, value):
         if value is None:
             return None
         if not isinstance(value, EUI):
-            value = EUI(value, dialect=default_dialect())
+            value = self.to_python(value)
             if self.integer:
                 return int(value)
             return str(value)
@@ -57,12 +57,16 @@ class MACAddressField(models.Field):
         if self.integer:
             return int(value)
         return str(value)
-    
+
     def get_internal_type(self):
         if self.integer:
             return 'BigIntegerField'
         return 'CharField'
-            
+
+    # @todo: remove context parameter when facing out django < 2.0 support
+    def from_db_value(self, value, expression, connection, context=None):
+        return self.to_python(value)
+
     def to_python(self, value):
         if value is None:
             return value
@@ -70,7 +74,7 @@ class MACAddressField(models.Field):
             value.dialect = default_dialect(value)
             return value
         try:
-            return EUI(value, dialect=default_dialect())
+            return EUI(value, version=48, dialect=default_dialect())
         except (TypeError, ValueError, AddrFormatError):
             raise ValidationError(
                 "This value must be a valid MAC address.")
@@ -88,9 +92,21 @@ class MACAddressField(models.Field):
                 return self.get_prep_value(value)
             except AddrFormatError:
                 return None
+        elif lookup_type in ('in'):
+            try:
+                macs = []
+                for mac in value:
+                    macs += [self.get_prep_value(mac)]
+                return macs
+            except AddrFormatError:
+                return None
         else:
             raise TypeError('Lookup type %r not supported.' % lookup_type)
 
+if django.VERSION < (1, 8):
+    from django.utils.six import add_metaclass
+    MACAddressField = add_metaclass(models.SubfieldBase)(MACAddressField)
+
 try:
     from south.modelsinspector import add_introspection_rules
     add_introspection_rules([], ["^macaddress\.fields\.MACAddressField"])
